.. image:: https://img.shields.io/pypi/v/scikit-mine.svg
    :target: https://pypi.python.org/pypi/scikit-mine/


.. image:: https://codecov.io/gh/remiadon/scikit-mine/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/remiadon/scikit-mine
        
.. image:: https://img.shields.io/badge/powered%20by-INRIA-orange.svg?style=flat&colorA=384257&colorB=E23324
  :target: https://www.inria.fr/en

.. image:: https://pepy.tech/badge/scikit-mine
  :target: https://pepy.tech/project/scikit-mine

.. image:: https://mybinder.org/badge_logo.svg
 :target: https://mybinder.org/v2/gh/scikit-mine/scikit-mine/HEAD?filepath=docs%2Ftutorials%2Fperiodic%2Fperiodic_canadian_tv.ipynb


Scikit-mine : pattern mining in Python

* **Descriptive analysis**, leading to **interpretable**, concise descriptions using the `Minimum Description Length Principle <https://en.wikipedia.org/wiki/Minimum_description_length>`_
* **Fast** Algorithms
* **Simple, extendable API**, inspired by scikit-learn_

.. _scikit-learn: https://scikit-learn.org/


Resources
---------

* Free software: BSD license
* GitHub: https://github.com/scikit-mine/scikit-mine
* Documentation: https://scikit-mine.github.io/scikit-mine/


Quickstart
----------


scikit-mine is a Python module for pattern mining built on top of
Pandas/Numpy/SciPy and is distributed under the 3-Clause BSD license.

It is currently maintained by a team of volunteers.

See examples in the tutorials; the notebooks are available here_.


.. _here: https://github.com/scikit-mine/scikit-mine/tree/master/docs/tutorials


Dependencies
------------

scikit-mine requires Python>=3.7,
and some extra dependencies

* scipy>=1.2.1
* pandas>=1.0.0
* pyroaring
* joblib>=0.11.1
* sortedcontainers>=2.1.0
* dataclasses
* networkx~=2.5.1
* wget

**scikit-learn** is not a dependency. However, scikit-mine is **contiuously tested for interactions with scikit-learn**

Development
-----------

This project is funded by the `INRIA center in Rennes, Brittany, France <https://www.inria.fr/fr/centre-inria-rennes-bretagne-atlantique>`_.

We welcome new contributors of all experience levels. 


Internal Contributors
---------------------

- Rémi Adon (https://github.com/remiadon)
- Luis Galárraga (https://github.com/lgalarra)
- Josie Signe (https://github.com/Darlysia)
- Esther Galbrun (https://github.com/nurblageij)
- Hermann Courteille (https://github.com/hermann74)
- Cyril Regan (https://github.com/cyril-data)
- Thomas Betton (https://github.com/thomasbtnfr)
